@@ -19,7 +19,7 @@ class AssistantManager:
         self.instructions = instructions
         self.tools = tools
         self.name = name
-        self.additional_instructions = None
+        self.tool_call_arguments = None
 
         if assistant_id is not None:
             self.assistant = self.client.beta.assistants.retrieve(assistant_id)
@@ -66,7 +66,7 @@ class AssistantManager:
         print("Thread generated:", thread)
         return thread
 
-    def stream_thread(self, content, tool = None, thread_id: str = None, thread = None):
+    def stream_thread(self, content, tool_choice = None, thread_id: str = None, thread = None, additional_instructions = None):
         if thread_id is not None:
             thread = self.client.beta.threads.retrieve(thread_id)
         elif thread is None:
@@ -74,10 +74,14 @@ class AssistantManager:
 
         assistant = self.assistant
         event_handler = AstraEventHandler(self.client)
-        tool_choice = None
-        if tool is not None:
-            event_handler.register_tool(tool)
-            tool_choice = tool.tool_choice_object()
+        if self.tools is not None:
+            for tool in self.tools:
+                event_handler.register_tool(tool)
+        if tool_choice is not None:
+            if hasattr(tool_choice, 'tool_choice_object'):
+                tool_choice = tool_choice.tool_choice_object()
+            else:
+                tool_choice = tool_choice
         try:
             self.client.beta.threads.messages.create(
                 thread_id=thread.id, role="user", content=content
@@ -86,7 +90,7 @@ class AssistantManager:
                 "thread_id": thread.id,
                 "assistant_id": assistant.id,
                 "event_handler": event_handler,
-                "additional_instructions": self.additional_instructions
+                "additional_instructions": additional_instructions
             }
             # Conditionally add 'tool_choice' if it's not None
             if tool_choice is not None:
@@ -98,8 +102,11 @@ class AssistantManager:
                     yield text
 
             tool_call_results = None
+            tool_call_arguments = None
+            self.tool_call_arguments = event_handler.arguments
             if event_handler.stream is not None:
-                yield event_handler.tool_call_results
+                if event_handler.tool_call_results is not None:
+                    yield event_handler.tool_call_results
                 with event_handler.stream as stream:
                     for text in stream.text_deltas:
                         yield text
@@ -107,7 +114,7 @@ class AssistantManager:
             print(e)
             raise e
         
-    async def run_thread(self, content, tool = None, thread_id: str = None, thread = None) -> ToolOutput:
+    async def run_thread(self, content, tool = None, thread_id: str = None, thread = None, additional_instructions = None) -> ToolOutput:
         if thread_id is not None:
             thread = self.client.beta.threads.retrieve(thread_id)
         elif thread is None:
@@ -127,7 +134,7 @@ class AssistantManager:
                 "thread_id": thread.id,
                 "assistant_id": assistant.id,
                 "event_handler": event_handler,
-                "additional_instructions": self.additional_instructions
+                "additional_instructions": additional_instructions
             }
             # Conditionally add 'tool_choice' if it's not None
             if tool_choice is not None:
